( cd boot ; rm -rf uinitrd-tegra )
( cd boot ; ln -sf uinitrd-tegra-3.4.11 uinitrd-tegra )
( cd boot ; rm -rf uImage-tegra )
( cd boot ; ln -sf uImage-tegra-3.4.11 uImage-tegra )
( cd boot ; rm -rf System.map-tegra )
( cd boot ; ln -sf System.map-tegra-3.4.11 System.map-tegra )
